==> python-numarray_1.0.orig.tar.gz: python-numarray-1.0.orig/Packages/nd_image/Src/ni_filters.h <==
/* Copyright (C) 2003, 2004 Peter J. Verveer
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met: 
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials provided
 *    with the distribution.
 *
 * 3. The name of the author may not be used to endorse or promote
 *    products derived from this software without specific prior
 *    written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
 * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.      
 */

#ifndef NI_FILTERS_H
#define NI_FILTERS_H

int NI_Correlate1D(PyArrayObject*, double*, int, int, PyArrayObject**,
                   PyObject*, NI_ExtendMode, double, int, NumarrayType);

int NI_Correlate(PyArrayObject*, PyArrayObject*, PyArrayObject*, 
                 PyArrayObject**, PyObject*, NI_ExtendMode, double, int*, 
                 NumarrayType);

int NI_BoxcarFilter1D(PyArrayObject*, int, int, PyArrayObject**, PyObject*, 
                      NI_ExtendMode, double, int, NumarrayType);

int NI_MinimumMaximumFilter1D(PyArrayObject*, int, int, PyArrayObject**, 
                              PyObject*, NI_ExtendMode, double, int, char);

int NI_MinimumMaximumFilter(PyArrayObject*, PyArrayObject*, PyArrayObject*,
                            PyArrayObject**, PyObject*, NI_ExtendMode,
                            double, int*, char);

int NI_RankFilter(PyArrayObject*, int, double, PyArrayObject*,
                  PyArrayObject**, PyObject*, NI_ExtendMode, double, int*,
                  char);
                  
int NI_GenericFilter(PyArrayObject*, 
                     int (*)(double*, int, double*, void*),
                     void *, PyArrayObject*, PyArrayObject**, PyObject*, 
                     NI_ExtendMode, double, int*, NumarrayType);
                     
int NI_GenericFilter1D(PyArrayObject *, 
                       int (*)(double*, int, double*, int, void*),
                       void*, int, int, PyArrayObject**, PyObject*,
                       NI_ExtendMode, double, int, NumarrayType);

#endif

==> python-numarray_1.3.2.orig.tar.gz: python-numarray-1.3.2.orig/Packages/nd_image/Src/ni_filters.h <==
/* Copyright (C) 2003-2005 Peter J. Verveer
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met: 
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials provided
 *    with the distribution.
 *
 * 3. The name of the author may not be used to endorse or promote
 *    products derived from this software without specific prior
 *    written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
 * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.      
 */

#ifndef NI_FILTERS_H
#define NI_FILTERS_H

int NI_Correlate1D(PyArrayObject*, double*, int, int, PyArrayObject*,
                   NI_ExtendMode, double, int);
int NI_Correlate(PyArrayObject*, PyArrayObject*, PyArrayObject*, 
                 PyArrayObject*, NI_ExtendMode, double, int*);
int NI_UniformFilter1D(PyArrayObject*, int, int, PyArrayObject*,
                       NI_ExtendMode, double, int);
int NI_MinimumMaximumFilter1D(PyArrayObject*, int, int, PyArrayObject*, 
                              NI_ExtendMode, double, int, char);
int NI_MinimumMaximumFilter(PyArrayObject*, PyArrayObject*, PyArrayObject*,
                       PyArrayObject*, NI_ExtendMode, double, int*, char);
int NI_RankFilter(PyArrayObject*, int, double, PyArrayObject*,
                        PyArrayObject*, NI_ExtendMode, double, int*, char);
int NI_GenericFilter(PyArrayObject*, int (*)(double*, int, double*, void*),
      void *, PyArrayObject*, PyArrayObject*, NI_ExtendMode, double, int*);
int NI_GenericFilter1D(PyArrayObject *, int (*)(double*, int, double*, int,
      void*), void*, int, int, PyArrayObject*, NI_ExtendMode, double, int);

#endif
